@@ -47,7 +47,7 @@ void Config::load()
     data.general.metaDataOutputDirectory = group.readEntry( "metaDataOutputDirectory", QDir::homePath() + "/soundKonverter/%b/%d - %n - %a - %t" );
     data.general.copyStructureOutputDirectory = group.readEntry( "copyStructureOutputDirectory", QDir::homePath() + "/soundKonverter" );
     data.general.useVFATNames = group.readEntry( "useVFATNames", true );
-    data.general.conflictHandling = group.readEntry( "conflictHandling", 0 );
+    data.general.conflictHandling = (Config::Data::General::ConflictHandling)group.readEntry( "conflictHandling", 0 );
 //     data.general.priority = group.readEntry( "priority", 10 );
     data.general.numFiles = group.readEntry( "numFiles", 0 );
     if( data.general.numFiles == 0 )
@@ -376,7 +376,7 @@ void Config::save()
     group.writeEntry( "metaDataOutputDirectory", data.general.metaDataOutputDirectory );
     group.writeEntry( "copyStructureOutputDirectory", data.general.copyStructureOutputDirectory );
     group.writeEntry( "useVFATNames", data.general.useVFATNames );
-    group.writeEntry( "conflictHandling", data.general.conflictHandling );
+    group.writeEntry( "conflictHandling", (int)data.general.conflictHandling );
 //     group.writeEntry( "priority", data.general.priority );
     group.writeEntry( "numFiles", data.general.numFiles );
     group.writeEntry( "updateDelay", data.general.updateDelay );
